<?php
/**
 * The Header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="content-vw">
 *
 * @package Law Advocate
 */

?><!DOCTYPE html>

<html <?php language_attributes(); ?>>

<head>
  <meta charset="<?php bloginfo( 'charset' ); ?>">
  <meta name="viewport" content="width=device-width">
  <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php if ( function_exists( 'wp_body_open' ) ) 
  {
    wp_body_open();
  }else{
    do_action('wp_body_open');
  } 
?>

<header role="banner" class="position-relative">
  <a class="screen-reader-text skip-link" href="#maincontent"><?php esc_html_e( 'Skip to content', 'law-advocate' ); ?></a>
  <div class="home-page-header">
    <div class="container">
      <div class="main-header-box">
        <div class="row">
          <div class="col-lg-3 col-md-3 logo-bdr">
            <div class="logo">   
              <?php if ( has_custom_logo() ) : ?>
                <div class="site-logo"><?php the_custom_logo(); ?></div>
              <?php endif; ?>
              <?php $blog_info = get_bloginfo( 'name' ); ?>
                <?php if ( ! empty( $blog_info ) ) : ?>
                  <?php if ( is_front_page() && is_home() ) : ?>
                  <?php if( get_theme_mod('vw_lawyer_attorney_logo_title_hide_show',true) == 1){ ?>
                    <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                  <?php } ?>
                  <?php else : ?>
                    <?php if( get_theme_mod('vw_lawyer_attorney_logo_title_hide_show',true) == 1){ ?>
                      <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                    <?php } ?>
                  <?php endif; ?>
                <?php endif; ?>
                <?php
                  $description = get_bloginfo( 'description', 'display' );
                  if ( $description || is_customize_preview() ) :
                ?>
                <?php if( get_theme_mod('vw_lawyer_attorney_tagline_hide_show',true) == 1){ ?>
                  <p class="site-description">
                    <?php echo esc_html( $description ); ?>
                  </p>
                <?php } ?>
              <?php endif; ?>
            </div>
          </div>
          <div class="col-lg-9 col-md-9 align-self-center">
            <?php if( get_theme_mod( 'vw_lawyer_attorney_call1') != '' || get_theme_mod('vw_lawyer_attorney_location') != '' || get_theme_mod('vw_lawyer_attorney_call') != '' || is_active_sidebar('social-links')) { ?>
              <div class="top-bar row me-lg-0 py-2">
                <div class="col-lg-9 col-md-9 align-self-center">
                  <div class="row">
                    <div class="col-lg-4 col-md-4 text-center align-self-center">
                      <?php if( get_theme_mod( 'vw_lawyer_attorney_call1') != '') { ?>
                        <span><i class="fas fa-envelope"></i><a href="mailto:<?php echo esc_attr(get_theme_mod('vw_lawyer_attorney_call1',''));?>"><?php echo esc_html(get_theme_mod('vw_lawyer_attorney_call1',''));?></a></span>
                      <?php }?>
                    </div>
                    <div class="col-lg-4 col-md-4 text-center align-self-center">
                      <?php if( get_theme_mod( 'vw_lawyer_attorney_location') != '') { ?>
                        <span><i class="fas fa-map-marker-alt"></i><?php echo esc_html(get_theme_mod('vw_lawyer_attorney_location',''));?></span>
                      <?php }?>
                    </div>
                    <div class="col-lg-4 col-md-4 text-center align-self-center">
                      <?php if( get_theme_mod( 'vw_lawyer_attorney_call') != '') { ?>
                        <span><i class="fas fa-phone"></i><a href="tel:<?php echo esc_attr( get_theme_mod('vw_lawyer_attorney_call','') ); ?>"><?php echo esc_html(get_theme_mod('vw_lawyer_attorney_call',''));?></a></span>
                      <?php }?>
                    </div>
                  </div>
                </div>
                <div class="col-lg-3 col-md-3 text-center align-self-center">
                  <?php dynamic_sidebar('social-links'); ?>
                </div>
              </div>
            <?php }?>
            <div class="header-menu py-2">
              <div class="row">
                <div class="align-self-center <?php if( get_theme_mod( 'law_advocate_header_contact_btn_link') != '' || get_theme_mod( 'law_advocate_header_contact_btn_text') != '') { ?>col-lg-8 col-md-7 col-3 <?php } else { ?>col-lg-11 col-md-10 <?php } ?> pe-lg-0" >
                  <div class="align-self-center">
                    <?php if(has_nav_menu('primary')){ ?>
                      <div class="toggle-nav mobile-menu">
                        <button onclick="vw_lawyer_attorney_menu_open_nav()" class="responsivetoggle"><i class="<?php echo esc_attr(get_theme_mod('vw_lawyer_attorney_res_open_menu_icon','fas fa-bars')); ?>"></i><span class="screen-reader-text"><?php esc_html_e('Open Button','law-advocate'); ?></span></button>
                      </div> 
                    <?php } ?>
                    <div id="mySidenav" class="nav sidenav">
                      <nav id="site-navigation" class="main-navigation" role="navigation" aria-label="<?php esc_attr_e( 'Top Menu', 'law-advocate' ); ?>">
                        <?php 
                          if(has_nav_menu('primary')){
                            wp_nav_menu( array( 
                              'theme_location' => 'primary',
                              'container_class' => 'main-menu clearfix' ,
                              'menu_class' => 'clearfix',
                              'items_wrap' => '<ul id="%1$s" class="%2$s mobile_nav">%3$s</ul>',
                              'fallback_cb' => 'wp_page_menu',
                            ) ); 
                          }
                        ?>
                        <a href="javascript:void(0)" class="closebtn mobile-menu" onclick="vw_lawyer_attorney_menu_close_nav()"><i class="<?php echo esc_attr(get_theme_mod('vw_lawyer_attorney_res_close_menu_icon','fas fa-times')); ?>"></i><span class="screen-reader-text"><?php esc_html_e('Close Button','law-advocate'); ?></span></a>
                      </nav>
                    </div>
                  </div>
                </div>
                <?php if( get_theme_mod( 'vw_lawyer_attorney_search_hide_show',true) == 1) { ?>
                <div class="col-lg-1 col-md-2 col-3 align-self-center">
                  <div class="search-box text-lg-center text-start">
                    <span><a href="#"><i class="<?php echo esc_attr(get_theme_mod('vw_lawyer_attorney_search_icon','fas fa-search')); ?>"></i></a></span>
                  </div>
                </div>
                <?php }?>
                <?php if( get_theme_mod( 'law_advocate_header_contact_btn_link') != '' || get_theme_mod( 'law_advocate_header_contact_btn_text') != '') { ?>
                  <div class="col-lg-3 col-md-3 col-6 align-self-center">
                    <div class="top-bar-btn text-center">
                      <a href="<?php echo esc_url(get_theme_mod('law_advocate_header_contact_btn_link','')) ?>" id="contact-btn"><?php echo esc_html(get_theme_mod('law_advocate_header_contact_btn_text','')) ?><span class="screen-reader-text"><?php esc_html_e( 'Contact Us','law-advocate' );?></span></a>
                    </div>
                  </div>
                <?php }?>
              </div>
            </div>
          </div>
        </div>
        <div class="serach_outer">
          <div class="closepop"><a href="#contact-btn"><i class="<?php echo esc_attr(get_theme_mod('vw_lawyer_attorney_search_close_icon','fa fa-window-close')); ?>"></i></a></div>
          <div class="serach_inner">
            <?php get_search_form(); ?>
          </div>
        </div>
      </div>
    </div>
  </div>
</header>

<?php if(get_theme_mod('vw_lawyer_attorney_loader_enable',false) == 1) { ?>
  <div id="preloader">
    <div class="loader-inner">
      <div class="loader-line-wrap">
        <div class="loader-line"></div>
      </div>
      <div class="loader-line-wrap">
        <div class="loader-line"></div>
      </div>
      <div class="loader-line-wrap">
        <div class="loader-line"></div>
      </div>
      <div class="loader-line-wrap">
        <div class="loader-line"></div>
      </div>
      <div class="loader-line-wrap">
        <div class="loader-line"></div>
      </div>
    </div>
  </div>
<?php } ?>